==========================
SLURM Completed Logs Utils
==========================

Collection of utilities for processing SLURM Completed Logs


Usage
-----

.. code-block:: shell

    pip install slurm-completed-logs-utils

Integrate into your code:

.. code-block:: python

    from slurm_completed_logs_utils import SlurmCompletedLogsParser as Parser

    infile = "/mnt/slurm/slurm_completed_jobs.log"
    parser = Parser()
    records = parser.get_records(infile)
    for record in records:
        print(f"job id: {record.jobid} status: {record.jobstate} name: {record.name}")


Exported console script
-----------------------

* slurm-log-to-sqlite: Convert SLURM Completed Logs to SQLite database
